OxmEncode

Trait OxmEncode 

pub trait OxmEncode {
    // Required method
    fn encode(&self) -> Vec<u8> ;
}
A trait for types that can be encoded to OXM/NXM wire format.

This provides a unified interface for encoding match fields regardless of whether they are OpenFlow Basic (OXM) or Nicira Extension (NXM) fields.

Required Methods

fn encode(&self) -> Vec<u8>

Encode this field to OXM wire format.

Returns a Vec<u8> containing the 4-byte OXM header followed by the field value (and mask, if applicable).

Implementors