FlowMonitorRequest

Struct FlowMonitorRequest 

pub struct FlowMonitorRequest {
    pub id: u32,
    pub flags: u16,
    pub out_port: u16,
    pub table_id: u8,
    pub match_fields: Match,
}
Builder for a flow monitor request.

Wire Format

+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
|                          monitor_id                           |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
|            flags            |           out_port              |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
|          match_len          |   table_id  |     pad           |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
|                    match (NXM/OXM TLVs)                       |
+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+

Fields

id: u32

Controller-assigned monitor ID.

flags: u16

Monitor flags (NXFMF_*).

out_port: u16

Required output port filter, or 0xffff for any.

table_id: u8

Table to monitor, or 0xff for all tables.

match_fields: Match

Match fields filter.

Implementations

Source

impl FlowMonitorRequest

pub fn new(id: u32) -> Self

Create a new flow monitor request with the given ID.

pub fn all_changes(id: u32) -> Self

Create a monitor for all flow changes in all tables.

Enables INITIAL, ADD, DELETE, MODIFY, and ACTIONS flags.

pub fn flags(self, flags: u16) -> Self

Set monitor flags.

pub fn table(self, table_id: u8) -> Self

Filter by table ID (0xff for all tables).

pub fn match_fields(self, m: Match) -> Self

Filter by match fields.

pub fn out_port(self, port: u16) -> Self

Filter by output port.

pub fn to_message(&self, version: Version, xid: u32) -> Message

Create the complete multipart request message.