pub trait OxmEncode {
// Required method
fn encode(&self) -> Vec<u8> ⓘ;
}Expand description
A trait for types that can be encoded to OXM/NXM wire format.
This provides a unified interface for encoding match fields regardless of whether they are OpenFlow Basic (OXM) or Nicira Extension (NXM) fields.